@@ -74,7 +74,7 @@ impl<K: Ord> SearchIndex<K> {
     /// #       search_index.insert(&index, element)
     /// #   );
     /// #
-    /// let autocomplete_options = search_index.autocomplete_keyword("E");
+    /// let autocomplete_options = search_index.autocomplete_keyword(&5, "E");
     ///
     /// assert_eq!(
     ///     // Convert `BTreeMap<&String>` to `Vec<&String>` for comparison:
@@ -84,7 +84,11 @@ impl<K: Ord> SearchIndex<K> {
     /// ```
 
     #[tracing::instrument(level = "trace", name = "Keyword Autocomplete", skip(self))]
-    pub(crate) fn autocomplete_keyword(&self, keyword: &str) -> Vec<&String> {
+    pub(crate) fn autocomplete_keyword(
+        &self,
+        maximum_autocomplete_options: &usize,
+        keyword: &str,
+    ) -> Vec<&String> {
 
         // If case sensitivity set, leave case intact. Otherwise, normalize
         // keyword to lower case:
@@ -93,6 +97,10 @@ impl<K: Ord> SearchIndex<K> {
             false => keyword.to_lowercase(),
         }; // match
 
+        // For debug builds:
+        #[cfg(debug_assertions)]
+        tracing::trace!("Autocompleting: {:?}", keyword);
+
         // Attempt to get matching keywords from `BTreeMap`:
         self.b_tree_map
             // Get matching keywords starting with (partial) keyword string:
@@ -110,8 +118,8 @@ impl<K: Ord> SearchIndex<K> {
             // it as a result. For example, if the user's keyword was "new" (as
             // in New York), do not return "new" as an auto-completed keyword:
             // .filter(|key| *key != &keyword)
-            // Only return `maximum_autocomplete_results` number of keywords:
-            .take(self.maximum_autocomplete_results)
+            // Only return `maximum_autocomplete_options` number of keywords:
+            .take(*maximum_autocomplete_options)
             // Collect all keyword autocompletions into a `Vec`:
             .collect()
 
