@@ -13,9 +13,10 @@ mod autocomplete_type;
 mod builder;
 mod default;
 mod deref;
+mod dump_keyword;
 mod indexable;
 mod insert;
-mod maximum_keys_per_keyword;
+mod max_keys_per_keyword;
 mod new;
 mod remove;
 mod replace;
